@@ -18,9 +18,9 @@
  */
 package org.apache.commons.compress.archivers.memory;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.io.IOException;
 
@@ -32,27 +32,23 @@ public final class MemoryArchiveTestCase {
     @Test
     public void testReading() throws IOException {
 
-        final MemoryArchiveInputStream is = new MemoryArchiveInputStream(new String[][] {
-                { "test1",     "content1" },
-                { "test2",     "content2" },
-                });
+        try (MemoryArchiveInputStream is = new MemoryArchiveInputStream(new String[][] { { "test1", "content1" }, { "test2", "content2" } })) {
 
-        final ArchiveEntry entry1 = is.getNextEntry();
-        assertNotNull(entry1);
-        assertEquals("test1", entry1.getName());
-        final String content1 = is.readString();
-        assertEquals("content1", content1);
+            final ArchiveEntry entry1 = is.getNextEntry();
+            assertNotNull(entry1);
+            assertEquals("test1", entry1.getName());
+            final String content1 = is.readString();
+            assertEquals("content1", content1);
 
-        final ArchiveEntry entry2 = is.getNextEntry();
-        assertNotNull(entry2);
-        assertEquals("test2", entry2.getName());
-        final String content2 = is.readString();
-        assertEquals("content2", content2);
+            final ArchiveEntry entry2 = is.getNextEntry();
+            assertNotNull(entry2);
+            assertEquals("test2", entry2.getName());
+            final String content2 = is.readString();
+            assertEquals("content2", content2);
 
-        final ArchiveEntry entry3 = is.getNextEntry();
-        assertNull(entry3);
-
-        is.close();
+            final ArchiveEntry entry3 = is.getNextEntry();
+            assertNull(entry3);
+        }
     }
 
 }
