@@ -20,19 +20,17 @@ package org.apache.commons.compress.archivers.zip;
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.commons.compress.AbstractTestCase.mkdir;
 import static org.apache.commons.compress.AbstractTestCase.rmdir;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.file.Files;
 import java.util.Arrays;
 
-import org.apache.commons.compress.utils.IOUtils;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -41,56 +39,6 @@ public class DataDescriptorTest {
 
     private File dir;
 
-    @BeforeEach
-    public void setUp() throws Exception {
-        dir = mkdir("ddtest");
-    }
-
-    @AfterEach
-    public void tearDown() {
-        rmdir(dir);
-    }
-
-    @Test
-    public void writesDataDescriptorForDeflatedEntryOnUnseekableOutput() throws IOException {
-        final ByteArrayOutputStream o = new ByteArrayOutputStream();
-        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(o)) {
-            zos.putArchiveEntry(new ZipArchiveEntry("test1.txt"));
-            zos.write("foo".getBytes(UTF_8));
-            zos.closeArchiveEntry();
-        }
-        final byte[] data = o.toByteArray();
-
-        final byte[] versionInLFH = Arrays.copyOfRange(data, 4, 6);
-        // 2.0 because of DD
-        assertArrayEquals(new byte[] { 20, 0 }, versionInLFH);
-        final byte[] gpbInLFH = Arrays.copyOfRange(data, 6, 8);
-        // DD and EFS flags
-        assertArrayEquals(new byte[] { 8, 8 }, gpbInLFH);
-        final byte[] crcAndSizedInLFH = Arrays.copyOfRange(data, 14, 26);
-        assertArrayEquals(new byte[12], crcAndSizedInLFH);
-
-        final int cdhStart = findCentralDirectory(data);
-        final byte[] versionInCDH = Arrays.copyOfRange(data, cdhStart + 6, cdhStart + 8);
-        assertArrayEquals(new byte[] { 20, 0 }, versionInCDH);
-        final byte[] gpbInCDH = Arrays.copyOfRange(data, cdhStart + 8, cdhStart + 10);
-        assertArrayEquals(new byte[] { 8, 8 }, gpbInCDH);
-
-        final int ddStart = cdhStart - 16;
-        assertEquals(ZipLong.DD_SIG, new ZipLong(data, ddStart));
-        final long crcFromDD = ZipLong.getValue(data, ddStart + 4);
-        final long cSizeFromDD = ZipLong.getValue(data, ddStart + 8);
-        final long sizeFromDD = ZipLong.getValue(data, ddStart + 12);
-        assertEquals(3, sizeFromDD);
-
-        final long crcFromCDH = ZipLong.getValue(data, cdhStart + 16);
-        assertEquals(crcFromDD, crcFromCDH);
-        final long cSizeFromCDH = ZipLong.getValue(data, cdhStart + 20);
-        assertEquals(cSizeFromDD, cSizeFromCDH);
-        final long sizeFromCDH = ZipLong.getValue(data, cdhStart + 24);
-        assertEquals(sizeFromDD, sizeFromCDH);
-    }
-
     @Test
     public void doesntWriteDataDescriptorForDeflatedEntryOnSeekableOutput() throws IOException {
         final File f = new File(dir, "test.zip");
@@ -100,10 +48,7 @@ public class DataDescriptorTest {
             zos.closeArchiveEntry();
         }
 
-        final byte[] data;
-        try (InputStream fis = Files.newInputStream(f.toPath())) {
-            data = IOUtils.toByteArray(fis);
-        }
+        final byte[] data = Files.readAllBytes(f.toPath());
 
         final byte[] versionInLFH = Arrays.copyOfRange(data, 4, 6);
         // still 2.0 because of Deflate
@@ -188,4 +133,54 @@ public class DataDescriptorTest {
         // not a ZIP64 archive, no comment, "End of central directory record" at the end
         return (int) ZipLong.getValue(data, data.length - 22 + 16);
     }
+
+    @BeforeEach
+    public void setUp() throws Exception {
+        dir = mkdir("ddtest");
+    }
+
+    @AfterEach
+    public void tearDown() {
+        rmdir(dir);
+    }
+
+    @Test
+    public void writesDataDescriptorForDeflatedEntryOnUnseekableOutput() throws IOException {
+        final ByteArrayOutputStream o = new ByteArrayOutputStream();
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(o)) {
+            zos.putArchiveEntry(new ZipArchiveEntry("test1.txt"));
+            zos.write("foo".getBytes(UTF_8));
+            zos.closeArchiveEntry();
+        }
+        final byte[] data = o.toByteArray();
+
+        final byte[] versionInLFH = Arrays.copyOfRange(data, 4, 6);
+        // 2.0 because of DD
+        assertArrayEquals(new byte[] { 20, 0 }, versionInLFH);
+        final byte[] gpbInLFH = Arrays.copyOfRange(data, 6, 8);
+        // DD and EFS flags
+        assertArrayEquals(new byte[] { 8, 8 }, gpbInLFH);
+        final byte[] crcAndSizedInLFH = Arrays.copyOfRange(data, 14, 26);
+        assertArrayEquals(new byte[12], crcAndSizedInLFH);
+
+        final int cdhStart = findCentralDirectory(data);
+        final byte[] versionInCDH = Arrays.copyOfRange(data, cdhStart + 6, cdhStart + 8);
+        assertArrayEquals(new byte[] { 20, 0 }, versionInCDH);
+        final byte[] gpbInCDH = Arrays.copyOfRange(data, cdhStart + 8, cdhStart + 10);
+        assertArrayEquals(new byte[] { 8, 8 }, gpbInCDH);
+
+        final int ddStart = cdhStart - 16;
+        assertEquals(ZipLong.DD_SIG, new ZipLong(data, ddStart));
+        final long crcFromDD = ZipLong.getValue(data, ddStart + 4);
+        final long cSizeFromDD = ZipLong.getValue(data, ddStart + 8);
+        final long sizeFromDD = ZipLong.getValue(data, ddStart + 12);
+        assertEquals(3, sizeFromDD);
+
+        final long crcFromCDH = ZipLong.getValue(data, cdhStart + 16);
+        assertEquals(crcFromDD, crcFromCDH);
+        final long cSizeFromCDH = ZipLong.getValue(data, cdhStart + 20);
+        assertEquals(cSizeFromDD, cSizeFromCDH);
+        final long sizeFromCDH = ZipLong.getValue(data, cdhStart + 24);
+        assertEquals(sizeFromDD, sizeFromCDH);
+    }
 }
