@@ -18,9 +18,9 @@
  */
 package org.apache.commons.compress.compressors.deflate;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
-import org.junit.Assert;
 import org.junit.jupiter.api.Test;
 
 public class DeflateParametersTest {
@@ -29,13 +29,7 @@ public class DeflateParametersTest {
     public void shouldBeAbleToSetCompressionLevel() {
         final DeflateParameters p = new DeflateParameters();
         p.setCompressionLevel(5);
-        Assert.assertEquals(5, p.getCompressionLevel());
-    }
-
-    @Test
-    public void shouldNotBeAbleToSetCompressionLevelToANegativeValue() {
-        final DeflateParameters p = new DeflateParameters();
-        assertThrows(IllegalArgumentException.class, () -> p.setCompressionLevel(DeflateParameters.MIN_LEVEL - 1));
+        assertEquals(5, p.getCompressionLevel());
     }
 
     @Test
@@ -43,4 +37,10 @@ public class DeflateParametersTest {
         final DeflateParameters p = new DeflateParameters();
         assertThrows(IllegalArgumentException.class, () -> p.setCompressionLevel(DeflateParameters.MAX_LEVEL + 1));
     }
+
+    @Test
+    public void shouldNotBeAbleToSetCompressionLevelToANegativeValue() {
+        final DeflateParameters p = new DeflateParameters();
+        assertThrows(IllegalArgumentException.class, () -> p.setCompressionLevel(DeflateParameters.MIN_LEVEL - 1));
+    }
 }
