@@ -16,6 +16,11 @@
  */
 package org.apache.commons.compress.harmony.unpack200.tests;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
@@ -33,193 +38,50 @@ import java.util.jar.JarOutputStream;
 import java.util.zip.ZipEntry;
 
 import org.apache.commons.compress.harmony.unpack200.Archive;
-
-import junit.framework.TestCase;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests for org.apache.commons.compress.harmony.unpack200.Archive, which is the main class for
  * unpack200.
  */
-public class ArchiveTest extends TestCase {
+public class ArchiveTest {
 
     InputStream in;
     JarOutputStream out;
     File file;
 
-    public void testJustResourcesGZip() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/JustResources.pack.gz");
-        file = File.createTempFile("Just", "ResourcesGz.jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive containing Harmony's SQL module, packed with -E1
-    public void testWithSqlE1() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/sql-e1.pack.gz");
-        file = File.createTempFile("sql-e1", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive containing Harmony's SQL module
-    public void testWithSql() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/sql.pack.gz");
-        file = File.createTempFile("sql", ".jar");
-        file.deleteOnExit();
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-        JarFile jarFile = new JarFile(file);
-
-        File compareFile = new File(Archive.class.getResource(
-                "/pack200/sqlUnpacked.jar").toURI());
-
-        JarFile jarFile2 = new JarFile(compareFile);
-
-        long differenceInJarSizes = Math.abs(compareFile.length()
-                - file.length());
-
-        assertTrue("Expected jar files to be a similar size, difference was "
-                + differenceInJarSizes + " bytes", differenceInJarSizes < 100);
-
-        Enumeration<JarEntry> entries = jarFile.entries();
-        Enumeration<JarEntry> entries2 = jarFile2.entries();
-        while(entries.hasMoreElements() && entries2.hasMoreElements()) {
-
-            JarEntry entry = entries.nextElement();
-            assertNotNull(entry);
-            String name = entry.getName();
-
-            JarEntry entry2 = entries2.nextElement();
-            assertNotNull(entry2);
-            String name2 = entry2.getName();
-
-            assertEquals(name, name2);
-
-            InputStream ours = jarFile.getInputStream(entry);
-            InputStream expected = jarFile2.getInputStream(entry2);
-
-            BufferedReader reader1 = new BufferedReader(new InputStreamReader(ours));
-            BufferedReader reader2 = new BufferedReader(new InputStreamReader(
-                    expected));
-            String line1 = reader1.readLine();
-            String line2 = reader2.readLine();
-            int i = 1;
-            while (line1 != null || line2 != null) {
-                assertEquals("Unpacked class files differ for " + name, line2, line1);
-                line1 = reader1.readLine();
-                line2 = reader2.readLine();
-                i++;
+    @AfterEach
+    public void tearDown() throws Exception {
+        if (in != null) {
+            try {
+                in.close();
+            } catch (final IOException e) {
+                e.printStackTrace();
             }
-            reader1.close();
-            reader2.close();
         }
+        try {
+            if (out != null) {
+                out.close();
+            }
+        } catch (final IOException e) {
+            e.printStackTrace();
+        }
+        file.delete();
     }
 
+    @Test
     public void testAlternativeConstructor() throws Exception {
-        String inputFile = new File(Archive.class
+        final String inputFile = new File(Archive.class
                 .getResource("/pack200/sql.pack.gz").toURI()).getPath();
         file = File.createTempFile("sql", ".jar");
         file.deleteOnExit();
-        String outputFile = file.getPath();
-        Archive archive = new Archive(inputFile, outputFile);
+        final String outputFile = file.getPath();
+        final Archive archive = new Archive(inputFile, outputFile);
         archive.unpack();
     }
 
-    // Test with an archive containing Harmony's Pack200 module, packed with -E1
-    public void testWithPack200E1() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/pack200-e1.pack.gz");
-        file = File.createTempFile("p200-e1", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive containing Harmony's Pack200 module
-    public void testWithPack200() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/pack200.pack.gz");
-        file = File.createTempFile("p200", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive containing Harmony's JNDI module
-    public void testWithJNDIE1() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/jndi-e1.pack.gz");
-        file = File.createTempFile("jndi-e1", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive containing Annotations
-    public void testWithAnnotations() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/annotations.pack.gz");
-        file = File.createTempFile("annotations", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with an archive packed with the -E0 option
-    public void testWithE0() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/simple-E0.pack.gz");
-        file = File.createTempFile("simple-e0", ".jar");
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-    // Test with a class containing lots of local variables (regression test for
-    // HARMONY-5470)
-    public void testWithLargeClass() throws Exception {
-        in = Archive.class
-                .getResourceAsStream("/pack200/LargeClass.pack.gz");
-        file = File.createTempFile("largeClass", ".jar");
-        file.deleteOnExit();
-        out = new JarOutputStream(new FileOutputStream(file));
-        Archive archive = new Archive(in, out);
-        archive.unpack();
-    }
-
-
-    public void testRemovePackFile() throws Exception {
-        File original = new File(Archive.class.getResource(
-                "/pack200/sql.pack.gz").toURI());
-        File copy = File.createTempFile("sqlcopy", ".pack.gz");
-        BufferedInputStream inputStream = new BufferedInputStream(
-                new FileInputStream(original));
-        BufferedOutputStream outputStream = new BufferedOutputStream(
-                new FileOutputStream(copy));
-        byte[] bytes = new byte[256];
-        int read = inputStream.read(bytes);
-        while (read > 0) {
-            outputStream.write(bytes, 0, read);
-            read = inputStream.read(bytes);
-        }
-        inputStream.close();
-        outputStream.close();
-        String inputFile = copy.getPath();
-        file = File.createTempFile("sqlout", ".jar");
-        file.deleteOnExit();
-        String outputFile = file.getPath();
-        Archive archive = new Archive(inputFile, outputFile);
-        archive.setRemovePackFile(true);
-        archive.unpack();
-        assertFalse(copy.exists());
-    }
-
+    @Test
     public void testDeflateHint() throws Exception {
         in = Archive.class
                 .getResourceAsStream("/pack200/sql.pack.gz");
@@ -245,27 +107,18 @@ public class ArchiveTest extends TestCase {
 
     }
 
-    @Override
-    protected void tearDown() throws Exception {
-        super.tearDown();
-        if (in != null) {
-            try {
-                in.close();
-            } catch (IOException e) {
-                e.printStackTrace();
-            }
-        }
-        try {
-            if (out != null) {
-                out.close();
-            }
-        } catch (IOException e) {
-            e.printStackTrace();
-        }
-        file.delete();
+    @Test
+    public void testJustResourcesGZip() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/JustResources.pack.gz");
+        file = File.createTempFile("Just", "ResourcesGz.jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
     }
 
     // Test verbose, quiet and log file options.
+    @Test
     public void testLoggingOptions() throws Exception {
         // test default option, which is quiet (no output at all)
         in = Archive.class
@@ -303,7 +156,7 @@ public class ArchiveTest extends TestCase {
         reader.close();
 
         // test append option
-        long length = logFile.length();
+        final long length = logFile.length();
         in = Archive.class
                 .getResourceAsStream("/pack200/sql.pack.gz");
         file = File.createTempFile("logtest", ".jar");
@@ -344,4 +197,168 @@ public class ArchiveTest extends TestCase {
         reader.close();
     }
 
+    @Test
+    public void testRemovePackFile() throws Exception {
+        final File original = new File(Archive.class.getResource(
+                "/pack200/sql.pack.gz").toURI());
+        final File copy = File.createTempFile("sqlcopy", ".pack.gz");
+        final BufferedInputStream inputStream = new BufferedInputStream(
+                new FileInputStream(original));
+        final BufferedOutputStream outputStream = new BufferedOutputStream(
+                new FileOutputStream(copy));
+        final byte[] bytes = new byte[256];
+        int read = inputStream.read(bytes);
+        while (read > 0) {
+            outputStream.write(bytes, 0, read);
+            read = inputStream.read(bytes);
+        }
+        inputStream.close();
+        outputStream.close();
+        final String inputFile = copy.getPath();
+        file = File.createTempFile("sqlout", ".jar");
+        file.deleteOnExit();
+        final String outputFile = file.getPath();
+        final Archive archive = new Archive(inputFile, outputFile);
+        archive.setRemovePackFile(true);
+        archive.unpack();
+        assertFalse(copy.exists());
+    }
+
+    // Test with an archive containing Annotations
+    @Test
+    public void testWithAnnotations() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/annotations.pack.gz");
+        file = File.createTempFile("annotations", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+    // Test with an archive packed with the -E0 option
+    @Test
+    public void testWithE0() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/simple-E0.pack.gz");
+        file = File.createTempFile("simple-e0", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+    // Test with an archive containing Harmony's JNDI module
+    @Test
+    public void testWithJNDIE1() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/jndi-e1.pack.gz");
+        file = File.createTempFile("jndi-e1", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+    // Test with a class containing lots of local variables (regression test for
+    // HARMONY-5470)
+    @Test
+    public void testWithLargeClass() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/LargeClass.pack.gz");
+        file = File.createTempFile("largeClass", ".jar");
+        file.deleteOnExit();
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+
+    // Test with an archive containing Harmony's Pack200 module
+    @Test
+    public void testWithPack200() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/pack200.pack.gz");
+        file = File.createTempFile("p200", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+    // Test with an archive containing Harmony's Pack200 module, packed with -E1
+    @Test
+    public void testWithPack200E1() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/pack200-e1.pack.gz");
+        file = File.createTempFile("p200-e1", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
+    // Test with an archive containing Harmony's SQL module
+    @Test
+    public void testWithSql() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/sql.pack.gz");
+        file = File.createTempFile("sql", ".jar");
+        file.deleteOnExit();
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+        final JarFile jarFile = new JarFile(file);
+
+        final File compareFile = new File(Archive.class.getResource(
+                "/pack200/sqlUnpacked.jar").toURI());
+
+        final JarFile jarFile2 = new JarFile(compareFile);
+
+        final long differenceInJarSizes = Math.abs(compareFile.length()
+                - file.length());
+
+        assertTrue(differenceInJarSizes < 100, "Expected jar files to be a similar size, difference was "
+                + differenceInJarSizes + " bytes");
+
+        final Enumeration<JarEntry> entries = jarFile.entries();
+        final Enumeration<JarEntry> entries2 = jarFile2.entries();
+        while(entries.hasMoreElements() && entries2.hasMoreElements()) {
+
+            final JarEntry entry = entries.nextElement();
+            assertNotNull(entry);
+            final String name = entry.getName();
+
+            final JarEntry entry2 = entries2.nextElement();
+            assertNotNull(entry2);
+            final String name2 = entry2.getName();
+
+            assertEquals(name, name2);
+
+            final InputStream ours = jarFile.getInputStream(entry);
+            final InputStream expected = jarFile2.getInputStream(entry2);
+
+            final BufferedReader reader1 = new BufferedReader(new InputStreamReader(ours));
+            final BufferedReader reader2 = new BufferedReader(new InputStreamReader(
+                    expected));
+            String line1 = reader1.readLine();
+            String line2 = reader2.readLine();
+            int i = 1;
+            while (line1 != null || line2 != null) {
+                assertEquals(line2, line1, "Unpacked class files differ for " + name);
+                line1 = reader1.readLine();
+                line2 = reader2.readLine();
+                i++;
+            }
+            reader1.close();
+            reader2.close();
+        }
+    }
+
+    // Test with an archive containing Harmony's SQL module, packed with -E1
+    @Test
+    public void testWithSqlE1() throws Exception {
+        in = Archive.class
+                .getResourceAsStream("/pack200/sql-e1.pack.gz");
+        file = File.createTempFile("sql-e1", ".jar");
+        out = new JarOutputStream(new FileOutputStream(file));
+        final Archive archive = new Archive(in, out);
+        archive.unpack();
+    }
+
 }
