@@ -17,7 +17,9 @@
 
 package org.apache.commons.compress.utils;
 
-import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -29,7 +31,6 @@ import java.lang.reflect.Field;
 import java.nio.ByteBuffer;
 import java.nio.channels.ReadableByteChannel;
 
-import org.junit.Assert;
 import org.junit.jupiter.api.Test;
 
 public class IOUtilsTest {
@@ -38,35 +39,39 @@ public class IOUtilsTest {
         InputStream wrap(InputStream toWrap);
     }
 
-    @Test
-    public void skipUsingSkip() throws Exception {
-        skip(toWrap -> toWrap);
+    private static void readFully(final byte[] source, final ByteBuffer b) throws IOException {
+        IOUtils.readFully(new SeekableInMemoryByteChannel(source), b);
     }
 
     @Test
-    public void skipUsingRead() throws Exception {
-        skip(toWrap -> new FilterInputStream(toWrap) {
-            @Override
-            public long skip(final long s) {
-                return 0;
-            }
-        });
+    public void copyRangeDoesntCopyMoreThanAskedFor() throws IOException {
+        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 });
+             ByteArrayOutputStream out = new ByteArrayOutputStream()) {
+            assertEquals(3, IOUtils.copyRange(in, 3, out));
+            out.close();
+            assertArrayEquals(new byte[] { 1, 2, 3 }, out.toByteArray());
+        }
     }
 
     @Test
-    public void skipUsingSkipAndRead() throws Exception {
-        skip(toWrap -> new FilterInputStream(toWrap) {
-            boolean skipped;
-            @Override
-            public long skip(final long s) throws IOException {
-                if (!skipped) {
-                    toWrap.skip(5);
-                    skipped = true;
-                    return 5;
-                }
-                return 0;
-            }
-        });
+    public void copyRangeStopsIfThereIsNothingToCopyAnymore() throws IOException {
+        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 });
+             ByteArrayOutputStream out = new ByteArrayOutputStream()) {
+            assertEquals(5, IOUtils.copyRange(in, 10, out));
+            out.close();
+            assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, out.toByteArray());
+        }
+    }
+
+    @Test
+    public void copyRangeThrowsOnZeroBufferSize() {
+        assertThrows(IllegalArgumentException.class,
+            () -> IOUtils.copyRange(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), 5, new ByteArrayOutputStream(), 0));
+    }
+
+    @Test
+    public void copyThrowsOnZeroBufferSize() {
+        assertThrows(IllegalArgumentException.class, () -> IOUtils.copy(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), new ByteArrayOutputStream(), 0));
     }
 
     @Test
@@ -77,11 +82,11 @@ public class IOUtilsTest {
             source[i] = i;
         }
         readFully(source, b);
-        Assert.assertArrayEquals(source, b.array());
+        assertArrayEquals(source, b.array());
     }
 
     @Test
-    public void readFullyOnChannelThrowsEof() throws IOException {
+    public void readFullyOnChannelThrowsEof() {
         final ByteBuffer b = ByteBuffer.allocate(21);
         final byte[] source = new byte[20];
         for (byte i = 0; i < 20; i++) {
@@ -90,63 +95,14 @@ public class IOUtilsTest {
         assertThrows(EOFException.class, () -> readFully(source, b));
     }
 
-    @Test
-    public void copyThrowsOnZeroBufferSize() throws IOException {
-        assertThrows(IllegalArgumentException.class, () -> IOUtils.copy(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), new ByteArrayOutputStream(), 0));
-    }
-
-    @Test
-    public void copyRangeThrowsOnZeroBufferSize() throws IOException {
-        assertThrows(IllegalArgumentException.class,
-            () -> IOUtils.copyRange(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), 5, new ByteArrayOutputStream(), 0));
-    }
-
-    @Test
-    public void copyRangeDoesntCopyMoreThanAskedFor() throws IOException {
-        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 });
-             ByteArrayOutputStream out = new ByteArrayOutputStream()) {
-            Assert.assertEquals(3, IOUtils.copyRange(in, 3, out));
-            out.close();
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3 }, out.toByteArray());
-        }
-    }
-
-    @Test
-    public void copyRangeStopsIfThereIsNothingToCopyAnymore() throws IOException {
-        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 });
-             ByteArrayOutputStream out = new ByteArrayOutputStream()) {
-            Assert.assertEquals(5, IOUtils.copyRange(in, 10, out));
-            out.close();
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, out.toByteArray());
-        }
-    }
-
-    @Test
-    public void readRangeFromStreamDoesntReadMoreThanAskedFor() throws IOException {
-        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 })) {
-            byte[] read = IOUtils.readRange(in, 3);
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3 }, read);
-            Assert.assertEquals(4, in.read());
-        }
-    }
-
-    @Test
-    public void readRangeFromStreamStopsIfThereIsNothingToReadAnymore() throws IOException {
-        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 })) {
-            byte[] read = IOUtils.readRange(in, 10);
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
-            Assert.assertEquals(-1, in.read());
-        }
-    }
-
     @Test
     public void readRangeFromChannelDoesntReadMoreThanAskedFor() throws IOException {
         try (ReadableByteChannel in = new SeekableInMemoryByteChannel(new byte[] { 1, 2, 3, 4, 5 })) {
-            byte[] read = IOUtils.readRange(in, 3);
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3 }, read);
+            final byte[] read = IOUtils.readRange(in, 3);
+            assertArrayEquals(new byte[] { 1, 2, 3 }, read);
             final ByteBuffer b = ByteBuffer.allocate(1);
-            Assert.assertEquals(1, in.read(b));
-            Assert.assertArrayEquals(new byte[] { 4 }, b.array());
+            assertEquals(1, in.read(b));
+            assertArrayEquals(new byte[] { 4 }, b.array());
         }
     }
 
@@ -165,7 +121,35 @@ public class IOUtilsTest {
             }
         }) {
             final byte[] read = IOUtils.readRange(in, 5);
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
+            assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
+        }
+    }
+
+    @Test
+    public void readRangeFromChannelStopsIfThereIsNothingToReadAnymore() throws IOException {
+        try (ReadableByteChannel in = new SeekableInMemoryByteChannel(new byte[] { 1, 2, 3, 4, 5 })) {
+            final byte[] read = IOUtils.readRange(in, 10);
+            assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
+            final ByteBuffer b = ByteBuffer.allocate(1);
+            assertEquals(-1, in.read(b));
+        }
+    }
+
+    @Test
+    public void readRangeFromStreamDoesntReadMoreThanAskedFor() throws IOException {
+        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 })) {
+            final byte[] read = IOUtils.readRange(in, 3);
+            assertArrayEquals(new byte[] { 1, 2, 3 }, read);
+            assertEquals(4, in.read());
+        }
+    }
+
+    @Test
+    public void readRangeFromStreamStopsIfThereIsNothingToReadAnymore() throws IOException {
+        try (ByteArrayInputStream in = new ByteArrayInputStream(new byte[] { 1, 2, 3, 4, 5 })) {
+            final byte[] read = IOUtils.readRange(in, 10);
+            assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
+            assertEquals(-1, in.read());
         }
     }
 
@@ -182,31 +166,48 @@ public class IOUtilsTest {
             // Ask for less than the input length, but more than the buffer size
             final int toRead = copyBufSize + 1;
             final byte[] read = IOUtils.readRange(in, toRead);
-            Assert.assertEquals(toRead, read.length);
-            Assert.assertEquals(toRead, in.position());
+            assertEquals(toRead, read.length);
+            assertEquals(toRead, in.position());
         }
     }
 
-    @Test
-    public void readRangeFromChannelStopsIfThereIsNothingToReadAnymore() throws IOException {
-        try (ReadableByteChannel in = new SeekableInMemoryByteChannel(new byte[] { 1, 2, 3, 4, 5 })) {
-            byte[] read = IOUtils.readRange(in, 10);
-            Assert.assertArrayEquals(new byte[] { 1, 2, 3, 4, 5 }, read);
-            final ByteBuffer b = ByteBuffer.allocate(1);
-            Assert.assertEquals(-1, in.read(b));
-        }
-    }
-
-    private static void readFully(final byte[] source, final ByteBuffer b) throws IOException {
-        IOUtils.readFully(new SeekableInMemoryByteChannel(source), b);
-    }
-
     private void skip(final StreamWrapper wrapper) throws Exception {
         final ByteArrayInputStream in = new ByteArrayInputStream(new byte[] {
                 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11
             });
         final InputStream sut = wrapper.wrap(in);
-        Assert.assertEquals(10, IOUtils.skip(sut, 10));
-        Assert.assertEquals(11, sut.read());
+        assertEquals(10, IOUtils.skip(sut, 10));
+        assertEquals(11, sut.read());
+    }
+
+    @Test
+    public void skipUsingRead() throws Exception {
+        skip(toWrap -> new FilterInputStream(toWrap) {
+            @Override
+            public long skip(final long s) {
+                return 0;
+            }
+        });
+    }
+
+    @Test
+    public void skipUsingSkip() throws Exception {
+        skip(toWrap -> toWrap);
+    }
+
+    @Test
+    public void skipUsingSkipAndRead() throws Exception {
+        skip(toWrap -> new FilterInputStream(toWrap) {
+            boolean skipped;
+            @Override
+            public long skip(final long s) throws IOException {
+                if (!skipped) {
+                    toWrap.skip(5);
+                    skipped = true;
+                    return 5;
+                }
+                return 0;
+            }
+        });
     }
 }
